Organization of templates
=========================

- admin: Overriding django admin templates
- bread: Contains basic skeleton templates, no styling
- carbon_design: Templates for Carbon Design System
- dynamic_preferences: Make sure current UI-framework is applied correctly to the dynamic preferences template
- registration: Make sure current UI-framework is applied correctly to the login templates
